<?php namespace wp_blank;

class UpdateTheme
{

    public function __construct(){
        
		$this->slug = get_option('template');
		$this->version = '0.0.0';
		$this->cacheKey = 'blank-custom-upd';
		$this->cacheAllowed = false;



        add_filter( 'themes_api', array( $this, 'Info' ), 20, 3 );
        add_filter( 'site_transient_update_themes', array( $this, 'Update' ) );
        add_action( 'upgrader_process_complete', array( $this, 'Purge' ), 10, 2 );

        /*thanks https://wordpress.stackexchange.com/questions/314701/remove-view-details-option-from-plugin-listing */
        //*
		add_filter('theme_row_meta',function ($plugin_meta, $plugin_file, $plugin_data, $status) {
			$pluginSlug = explode("/", $plugin_file)[0];
			$path = $_SERVER["REQUEST_SCHEME"] . "://" . $_SERVER["HTTP_HOST"] . "/wp-admin/" . (is_multisite()? "network/" : "");

			if($pluginSlug  == $this->slug)
				$plugin_meta[2] = "<a href=\"{$path}theme-install.php?theme={$pluginSlug}&action=theme_information&TB_iframe=true\" class=\"thickbox open-plugin-details-modal\">View details</a>";

			return $plugin_meta;
		},10,4);

		add_action( 'admin_enqueue_scripts', function($page)
		{
			if($page == "theme-install.php" && isset($_GET["theme"]) && $_GET["theme"] == dirname(get_template_directory()))
            {
                wp_enqueue_style( "ash-wp-style", "/wp-content/plugins/ash-wp/ash-wp-style.css", array(), null);
				//wp_enqueue_style( "ash-wp-style-form", plugin_dir_url( __FILE__ ) . "styles/forms.css", array(), null);
            }
                

		});
        //*/

    }
    
	
	private function Request($assoc = null){

		$remote = get_transient( $this->cacheKey );

		if( false === $remote || ! $this->cacheAllowed ) {

			$remote = wp_remote_get( AWP_BLANK_UPDATE_URL,
				array(
					'timeout' => 10,
					'headers' => array(
						'Accept' => 'application/json'
					)
				)
			);


			if(
				is_wp_error( $remote )
				|| 200 !== wp_remote_retrieve_response_code( $remote )
				|| empty( wp_remote_retrieve_body( $remote ) )
			) {
				return false;
			}

			set_transient( $this->cacheKey, $remote, DAY_IN_SECONDS );

		}

		$remote = json_decode( wp_remote_retrieve_body( $remote ), $assoc );
        

		return $remote;

	}

    public function Info($res, $action, $args )
    {
        // do nothing if it is not our plugin
        
        if( $this->slug !== $args->slug ) {
            return $res;
        }

        
        // do nothing if you're not getting plugin information right now
        if( 'theme_information' !== $action ) {
            return $res;
        }


        // get updates
        $remote = $this->Request();

        if( ! $remote ) {
            return $res;
        }

        return $remote;
    }
    
    public function Update($transient)
    {
    
        if ( empty($transient->checked ) ) {
            return $transient;
        }
    
        $remote = $this->Request(true);
    
        if(
            $remote
            && version_compare( $this->version, $remote["version"], '<' )
            && version_compare( $remote["requires"], get_bloginfo( 'version' ), '<' )
            && version_compare( $remote["requires_php"], PHP_VERSION, '<' )
        ) 
        {

            $remote["url"] = AWP_BLANK_UPDATE_URL;
            $remote["new_version"] = $remote["version"];
            $remote['package'] = $remote['download_link'];

            //var_dump($transient->response);
            $transient->response[$this->slug] = $remote;
    
        }
    
        //print_r($transient);
        return $transient;
    }
    
    public function Purge()
    {
    
        if (  $this->cacheAllowed && 'update' === $options['action'] && 'plugin' === $options[ 'type' ] ) {
            // just clean the cache when new plugin version is installed
            delete_transient( $this->cacheKey );
        }
    }
}

?>